import cli.app
import citrination_client
from citrination.util import determine_url


class App(cli.app.CommandLineApp):

    def main(self):
        """
        Upload a document.
        """
        url = determine_url(self.params.host, self.params.project)
        client = citrination_client.CitrinationClient(self.params.api_key, url)
        message = client.upload_file(self.params.file, self.params.data_set_id)
        if message is not None:
            print message
        else:
            print("Upload failed due to API server being unable to resolve the upload location.")

    def setup(self):
        """
        Setup this application.
        """
        cli.app.CommandLineApp.setup(self)
        self.add_param("-p", "--project", default=None, required=False,
                       help="Name of the project to connect to. This is equal to 'project' in "
                            "https://project.citrination.com. If not set, then a connection will be made to "
                            "https://citrination.com. This setting is superseded by --host if it is set.")
        self.add_param("--host", default=None, required=False,
                       help="Full host to connect, e.g. https://project.citrination.com. This supersedes --project if "
                            "both are set.")
        self.add_param("-k", "--api_key", help="Your API key for the project that you are connecting to.",
                       required=True)
        self.add_param("-f", "--file", help="Path to the file to upload.", required=True)
        self.add_param("-d", "--data_set_id", help="Id of the dataset to upload the file to.", required=True, type=int)

if __name__ == "__main__":
    adder = App()
    adder.run()



import cli.app


class CommandRouter(cli.app.CommandLineApp):
    """
    Route commands to applications.
    """
    apps = {}

    def setup(self):
        """
        Setup this router.
        """
        # Only two arguments should be sent to this app: the script name, and
        # the command/help flag. All arguments, save for this script name will
        # be sent to the command.
        if len(self.argv) > 1:
            self.proxied_argv = self.argv[1::]
            self.argv = self.argv[0:2]
        cli.app.CommandLineApp.setup(self)
        self.add_param('command', type=str, help="choose from: upload, create_dataset, create_dataset_version")

    def main(self):
        """
        Run the application.
        """
        command = self.params.command.lower()
        matched = self.match(command)

        # If an application is matched, run it; else, throw an error.
        if matched:
            app = matched(argv=self.proxied_argv)
            app.run()
        else:
            raise cli.app.Abort("Aborted: command not found: " + self.params.command)

    def match(self, command):
        """
        Iterate through the command registry to find a matching application.
        """
        for app, commands in self.apps.items():
            if command in commands:
                return app
        return False

    def register(self, app, commands):
        """
        Register an application with this router.
        """
        self.apps[app] = commands



import command_router
from citrination.commands import upload
from citrination.commands import create_dataset_version
from citrination.commands import create_dataset

app = command_router.CommandRouter()
app.register(upload.App, ['upload'])
app.register(create_dataset.App, ['create_dataset'])
app.register(create_dataset_version.App, ['create_dataset_version'])


def main():
    """
    Run the application.
    """
    app.run()

if __name__ == "__main__":
    main()



import cli.app
import citrination_client
from citrination.util import determine_url


class App(cli.app.CommandLineApp):

    def main(self):
        """
        Version a Citrination dataset.
        """
        url = determine_url(self.params.host, self.params.project)
        client = citrination_client.CitrinationClient(self.params.api_key, url)
        response = client.create_data_set_version(self.params.dataset)
        if response.status_code == 200:
            print("Data set version has been created.")
            print response.content
        else:
            print("Data set version creation failed.")

    def setup(self):
        """
        Setup this application.
        """
        cli.app.CommandLineApp.setup(self)
        self.add_param("-p", "--project", default=None, required=False,
                       help="Name of the project to connect to. This is equal to 'project' in "
                            "https://project.citrination.com. If not set, then a connection will be made to "
                            "https://citrination.com. This setting is superseded by --host if it is set.")
        self.add_param("--host", default=None, required=False,
                       help="Full host to connect, e.g. https://project.citrination.com. This supersedes --project if "
                            "both are set.")
        self.add_param("-k", "--api_key", help="Your API key for the project that you are connecting to.",
                       required=True)
        self.add_param("-d", "--dataset", help="Id of the dataset to create a new version for.", required=True,
                       type=int)

if __name__ == "__main__":
    adder = App()
    adder.run()



def determine_url(host, project):
    """
    Determine the URL to use when connecting to a host.

    :param host: Full host name.
    :param project: Project name.
    :return: String with the URL to use.
    """
    host = host if host is None else host.strip()
    if host is not None and len(host) > 0:
        return host
    project = project if project is None else project.strip()
    if project is not None and len(project) > 0:
        return 'https://' + project + '.citrination.com'
    return 'https://citrination.com'



from setuptools import setup, find_packages

setup(name='citrination',
      version='1.0.3',
      url='http://github.com/CitrineInformatics/python-citrination-cli',
      description='Command line interface for interacting with Citrination sites',
      packages=find_packages(),
      install_requires=[
            'argparse',
            'pyCLI==2.0.3',
            'citrination-client==1.1.11'
      ],
      entry_points={
            'console_scripts': [
                  'citrination=citrination.__main__:main'
            ]
      })
